%if %{?fedora}%{!?fedora:0} >= 25 || %{?rhel}%{!?rhel:0} >= 8
%global use_systemd 1
%else
%global use_systemd 0
%endif

Name:		nordugrid-arc-gangliarc
Version:	1.0.2
Release:	1%{?dist}
Summary:	Ganglia monitoring for ARC services
License:	ASL 2.0
URL:		http://wiki.nordugrid.org/index.php/Gangliarc
Source0:	http://download.nordugrid.org/packages/%{name}/releases/%{version}/src/%{name}-%{version}.tar.gz
BuildArch:	noarch

BuildRequires:	python2-devel
BuildRequires:	python-setuptools
%if %{use_systemd}
BuildRequires:	systemd-units
%endif

Requires:	nordugrid-arc-arex
Requires:	ganglia-gmond >= 3.0

%if %{use_systemd}
Requires(post):		systemd-units
Requires(preun):	systemd-units
Requires(postun):	systemd-units
%else
Requires(post):		chkconfig
Requires(preun):	chkconfig
Requires(preun):	initscripts
Requires(postun):	initscripts
%endif

%description
gangliarc provides a way to monitor ARC services through an existing ganglia
installation. Running gangliarc adds various ARC metrics to ganglia which can
then be viewed along with regular ganglia metrics for the ARC host.

%prep
%setup -q

%build
%{__python} -c 'import setuptools; execfile("setup.py")' build

%install
# /etc/init.d is hard-coded in setup.py so create a symlink to /etc/rc.d/init.d
# before installing
mkdir -p %{buildroot}%{_initddir}
ln -s %{buildroot}%{_initddir} %{buildroot}/etc/init.d

%{__python} -c 'import setuptools; execfile("setup.py")' install --root %{buildroot} --skip-build

# remove symlink
rm -f %{buildroot}/etc/init.d

%if %{use_systemd}
rm -rf %{buildroot}%{_initddir}
mkdir -p %{buildroot}%{_unitdir}
install -m 644 gangliarc.service %{buildroot}%{_unitdir}
mkdir -p %{buildroot}%{_datadir}/arc
install -m 755 gangliarc-start %{buildroot}%{_datadir}/arc
%endif

%if %{use_systemd}

%pre
# Remove old init config when systemd is used
/sbin/chkconfig --del gangliarc >/dev/null 2>&1 || :

%post
%systemd_post gangliarc.service

%preun
%systemd_preun gangliarc.service

%postun
%systemd_postun_with_restart gangliarc.service

%else

%post
/sbin/chkconfig --add gangliarc

%preun
if [ $1 -eq 0 ]; then
  /sbin/service gangliarc stop > /dev/null 2>&1
  /sbin/chkconfig --del gangliarc
fi

%postun
if [ $1 -ge 1 ]; then
  /sbin/service gangliarc condrestart > /dev/null 2>&1
fi

%endif

%files
%{python_sitelib}/gangliarc.*
%{python_sitelib}/nordugrid_arc_gangliarc-%{version}-py?.?.egg-info
%if %{use_systemd}
%{_unitdir}/gangliarc.service
%{_datadir}/arc/gangliarc-start
%else
%{_initddir}/gangliarc
%endif
%doc README
%{!?_licensedir: %doc LICENSE NOTICE}
%{?_licensedir: %license LICENSE NOTICE}

%changelog
* Fri Apr 07 2017 Mattias Ellert <mattias.ellert@physics.uu.se> - 1.0.2-1
- 1.0.2 Final release
- EPEL 5 End-Of-Life specfile clean-up

* Sat Feb 11 2017 Fedora Release Engineering <releng@fedoraproject.org> - 1.0.1-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_26_Mass_Rebuild

* Tue Sep 06 2016 Mattias Ellert <mattias.ellert@physics.uu.se> - 1.0.1-1
- 1.0.1 Final release

* Tue Jul 19 2016 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.0.0-4
- https://fedoraproject.org/wiki/Changes/Automatic_Provides_for_Python_RPM_Packages

* Thu Feb 04 2016 Fedora Release Engineering <releng@fedoraproject.org> - 1.0.0-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_24_Mass_Rebuild

* Fri Oct 23 2015 Mattias Ellert <mattias.ellert@fysast.uu.se> - 1.0.0-2
- Specfile clean-up before Fedora review submission

* Sun Dec 01 2013 Anders Waananen <waananen@nbi.dk> - 1.0.0-1
- 1.0.0 Final release

* Wed Jul 18 2012 David Cameron <d.g.cameron@fys.uio.no> 0.1.0-1
- Initial version
